@@ -1,8 +1,8 @@
 print.etm <- function(x, covariance = TRUE, whole = TRUE, ...) {
     if (!inherits(x, "etm"))
         stop("'x' must be of class 'etm'")
-    absorb <- setdiff(levels(x$tran$to), levels(x$trans$from))
-    transient <- unique(x$state.numbers[!(x$state.numbers %in% absorb)])
+    absorb <- setdiff(levels(x$trans$to), levels(x$trans$from))
+    transient <- unique(x$state.names[!(x$state.names %in% absorb)])
     cat(paste("Multistate model with", length(transient), "transient state(s)\n",
               "and", length(absorb), "absorbing state(s)\n\n", sep = " "))
     cat("Possible transitions:\n")
